@@ -49,10 +49,10 @@ class Query(Table, Monad):
         res.groupbys += other.groupbys
         return res
     
-    def __getitem__(self, col):
-        if isinstance(col, list):
-            return self.fmap(lambda x: L(*col).fmap(lambda y: getattr(x, y)).fold(lambda y, z: y % z))
-        return self.fmap(lambda x: getattr(x, col))
+    def __getitem__(self, cols):
+        if not isinstance(cols, str):
+            return self.fmap(lambda x: L(*cols).fmap(lambda y: getattr(x, y)).fold(lambda y, z: y % z))
+        return self.fmap(lambda x: getattr(x, cols))
     
     def getPrimary(self):
         for key, expr in self.columns.items():
@@ -395,11 +395,14 @@ class Query(Table, Monad):
         #     res.leftjoin = True
         #     return res
         
-        ljtables = res.columns.getTables() + self.dependents()
+        ljtables = res.columns.fmap(lambda x: x.getRef()).getTables() + self.dependents()
         for tab in ljtables:
             tab.leftjoin = True
         
         res.modify(lambda x: x.setWhere(False) if x.getTables() ^ ljtables else x, 'joincond')
+        for subq in res.subQueries():
+            subq.modify(lambda x: x.setWhere(False) if x.getTables() ^ ljtables else x, 'joincond')
+        
         # res.modify(lambda x: x.setWhere(False), 'joincond')
         # ifcond = res.joincond.children.filter(lambda x: x.getTables() <= res.dependents())
         
