@@ -418,7 +418,8 @@ def canMerge(self, subquery=False):
                    .filter(lambda x: x.isagg())\
                    .notExists()
     if not subquery and self.isagg():
-        subq = self.columns.values().filter(lambda x: not x.isagg() and x.getRef().isagg()).notExists()
+        subq = self.columns.values().filter(lambda x: not x.isagg() and not x.isPrimary()).notExists()
+        # subq = self.columns.values().filter(lambda x: not x.isagg() and x.getRef().isagg()).notExists()
     else:
         subq = True
     
